@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*
-import glob
-import sys,os
+import os
 import threading
-from multiprocessing import Array, Manager, Process
-from time import ctime, sleep
+from time import  sleep
 import serial.tools.list_ports
 import serial
 import mkpiano
@@ -37,7 +35,7 @@ class SerialPort():
         try:
             self._ser = serial.Serial(port,baudrate)
             self._ser.timeout = 0.01
-            sleep(2)
+            sleep(1)
             self._thread = threading.Thread(target=self._on_read,args=(self._callback,))
             self._thread.daemon = True
             self._thread.start()
@@ -46,7 +44,7 @@ class SerialPort():
             self._exit_thread.start()
             mkpiano.add_port(self)
         except Exception as ex:
-            print('$#&*@{"err_code":101,"err_msg":"串口被占用","device":"mkpiano","extra":{'+str(ex)+'}}@*&#$')
+            print('$#&*@{"err_code":101,"err_msg":"串口被占用","device":"mkpiano","extra":"'+str(ex)+'"}@*&#$')
 
     def setup(self,callback):
         self._responses.append(callback)
@@ -69,10 +67,9 @@ class SerialPort():
             if self.is_open():
                 # if self.in_waiting()>0:
                 buf = self.read()
-                if len(buf)==1:
-                    callback(buf[0])
-            # else:    
-            #     sleep(0.001)
+                for i in range(len(buf)):
+                    callback(buf[i])
+            sleep(0.001)
 
     def send(self,buffer):
         if self.is_open():
@@ -94,7 +91,7 @@ class SerialPort():
 
     def read(self):
         try:
-            return self._ser.read()
+            return self._ser.read(self.in_waiting())
         except serial.serialutil.SerialException as e:
             self.exiting = True
             print("\033[1;33m连接失败，未检测到设备\033[0m")
@@ -112,6 +109,7 @@ class SerialPort():
             if self.exiting:
                 self.exit()
                 break
+            sleep(0.001)
     def is_open(self):
         if not self._ser is None:
             return self._ser.isOpen()
